View Source Mix.Zoth (Zoth v1.0.1)

Utilities module for mix tasks.

Link to this section Summary

Functions

Raises an exception if the project is an umbrella app.

Parses argument options into a map.

Link to this section Functions

@spec no_umbrella!(binary()) :: :ok | no_return()

Raises an exception if the project is an umbrella app.

@spec otp_app() :: atom()
Link to this function

parse_options(args, switches, default_opts)

Parses argument options into a map.