View Source Zoth.PKCE.CodeChallenge (Zoth v1.0.1)

Link to this section Summary

Functions

Determine if the give challenge is valid based on the code challenge method.

Link to this section Functions

Link to this function

valid?(challenge, binary)

@spec valid?(challenge :: String.t(), method :: String.t()) :: boolean()

Determine if the give challenge is valid based on the code challenge method.

plain

Plain

Check to make sure that the verifier has the proper format and size.

s256

S256

The challenge should be a Base64 url encoded string that is the sha256 hash of the code verifier that will be presented in exchange for the access token.