View Source Mix.Zoth (Zoth v1.0.1)
Utilities module for mix tasks.
Link to this section Summary
Functions
Raises an exception if the project is an umbrella app.
Parses argument options into a map.
Link to this section Functions
Raises an exception if the project is an umbrella app.
@spec otp_app() :: atom()
@spec parse_options(OptionParser.argv(), Keyword.t(), Keyword.t()) :: {map(), OptionParser.argv(), OptionParser.errors()}
Parses argument options into a map.